==> intel-compute-runtime_19.13.12717.orig.tar.gz: compute-runtime-19.13.12717/unit_tests/api/api_tests_wrapper3.cpp <==
/*
 * Copyright (C) 2018 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "unit_tests/api/cl_get_kernel_work_group_info_tests.inl"
#include "unit_tests/api/cl_get_mem_object_info_tests.inl"
#include "unit_tests/api/cl_get_pipe_info_tests.inl"
#include "unit_tests/api/cl_get_platform_ids_tests.inl"
#include "unit_tests/api/cl_get_platform_info_tests.inl"
#include "unit_tests/api/cl_get_program_build_info_tests.inl"
#include "unit_tests/api/cl_get_program_info_tests.inl"
#include "unit_tests/api/cl_get_supported_image_formats_tests.inl"
#include "unit_tests/api/cl_icd_get_platform_ids_khr_tests.inl"
#include "unit_tests/api/cl_intel_accelerator_tests.inl"
#include "unit_tests/api/cl_link_program_tests.inl"
#include "unit_tests/api/cl_release_command_queue_tests.inl"
#include "unit_tests/api/cl_release_context_tests.inl"
#include "unit_tests/api/cl_release_event_tests.inl"
#include "unit_tests/api/cl_release_kernel_tests.inl"
#include "unit_tests/api/cl_release_mem_obj_tests.inl"
#include "unit_tests/api/cl_release_program_tests.inl"
#include "unit_tests/api/cl_retain_mem_obj_tests.inl"
#include "unit_tests/api/cl_retain_release_command_queue_tests.inl"
#include "unit_tests/api/cl_retain_release_context_tests.inl"
#include "unit_tests/api/cl_retain_release_device_tests.inl"
#include "unit_tests/api/cl_retain_release_sampler_tests.inl"
#include "unit_tests/api/cl_set_default_device_command_queue_tests.inl"
#include "unit_tests/api/cl_set_event_callback_tests.inl"
#include "unit_tests/api/cl_set_kernel_arg_svm_pointer_tests.inl"
#include "unit_tests/api/cl_set_kernel_exec_info_tests.inl"
#include "unit_tests/api/cl_set_mem_object_destructor_callback_tests.inl"
#include "unit_tests/api/cl_set_performance_configuration_tests.inl"
#include "unit_tests/api/cl_svm_alloc_tests.inl"
#include "unit_tests/api/cl_svm_free_tests.inl"
#include "unit_tests/api/cl_unload_compiler_tests.inl"
#include "unit_tests/api/cl_unload_platform_compiler_tests.inl"

==> intel-compute-runtime_19.39.14278.orig.tar.gz: compute-runtime-19.39.14278/unit_tests/api/api_tests_wrapper3.cpp <==
/*
 * Copyright (C) 2018-2019 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "unit_tests/api/cl_get_kernel_work_group_info_tests.inl"
#include "unit_tests/api/cl_get_mem_object_info_tests.inl"
#include "unit_tests/api/cl_get_pipe_info_tests.inl"
#include "unit_tests/api/cl_get_platform_ids_tests.inl"
#include "unit_tests/api/cl_get_platform_info_tests.inl"
#include "unit_tests/api/cl_get_program_build_info_tests.inl"
#include "unit_tests/api/cl_get_program_info_tests.inl"
#include "unit_tests/api/cl_get_supported_image_formats_tests.inl"
#include "unit_tests/api/cl_icd_get_platform_ids_khr_tests.inl"
#include "unit_tests/api/cl_intel_accelerator_tests.inl"
#include "unit_tests/api/cl_intel_tracing_tests.inl"
#include "unit_tests/api/cl_link_program_tests.inl"
#include "unit_tests/api/cl_release_command_queue_tests.inl"
#include "unit_tests/api/cl_release_context_tests.inl"
#include "unit_tests/api/cl_release_event_tests.inl"
#include "unit_tests/api/cl_release_kernel_tests.inl"
#include "unit_tests/api/cl_release_mem_obj_tests.inl"
#include "unit_tests/api/cl_release_program_tests.inl"
#include "unit_tests/api/cl_retain_mem_obj_tests.inl"
#include "unit_tests/api/cl_retain_release_command_queue_tests.inl"
#include "unit_tests/api/cl_retain_release_context_tests.inl"
#include "unit_tests/api/cl_retain_release_device_tests.inl"
#include "unit_tests/api/cl_retain_release_sampler_tests.inl"
#include "unit_tests/api/cl_set_default_device_command_queue_tests.inl"
#include "unit_tests/api/cl_set_event_callback_tests.inl"
#include "unit_tests/api/cl_set_kernel_arg_svm_pointer_tests.inl"
#include "unit_tests/api/cl_set_kernel_exec_info_tests.inl"
#include "unit_tests/api/cl_set_mem_object_destructor_callback_tests.inl"
#include "unit_tests/api/cl_set_performance_configuration_tests.inl"
#include "unit_tests/api/cl_set_program_specialization_constant_tests.inl"
#include "unit_tests/api/cl_svm_alloc_tests.inl"
#include "unit_tests/api/cl_svm_free_tests.inl"
#include "unit_tests/api/cl_unload_compiler_tests.inl"
#include "unit_tests/api/cl_unload_platform_compiler_tests.inl"
